@@ -37,7 +37,7 @@ import networkx as nx
 
 from jcvi.utils.cbook import fill
 from jcvi.formats.base import flexible_cast
-from jcvi.apps.base import sh, mkdir
+from jcvi.apps.base import cleanup, mkdir, sh
 from jcvi.algorithms.tsp import populate_edge_weights, node_to_edge
 
 
@@ -232,9 +232,7 @@ class GLPKSolver(AbstractMIPSolver):
         outfile = op.join(self.work_dir, "data.lp.out")  # verbose output
         listfile = op.join(self.work_dir, "data.lp.list")  # simple output
         # cleanup in case something wrong happens
-        for f in (outfile, listfile):
-            if op.exists(f):
-                os.remove(f)
+        cleanup(outfile, listfile)
 
         cmd = "glpsol --cuts --fpump --lp {0} -o {1} -w {2}".format(
             lpfile, outfile, listfile
@@ -310,8 +308,7 @@ class SCIPSolver(AbstractMIPSolver):
     def run(self, lpfile):
 
         outfile = self.work_dir + "/data.lp.out"  # verbose output
-        if op.exists(outfile):
-            os.remove(outfile)
+        cleanup(outfile)
 
         cmd = "scip -f {0} -l {1}".format(lpfile, outfile)
 
