@@ -22,6 +22,7 @@ from jcvi.apps.base import (
     OptionParser,
     OptionGroup,
     ActionDispatcher,
+    cleanup,
     need_update,
     popen,
     sh,
@@ -918,7 +919,7 @@ def consolidate(nbedfile, obedfile, cbedfile):
             b.accn = ";".join(accns)
         print(b, file=fp)
     fp.close()
-    os.remove(tmpfile)
+    cleanup(tmpfile)
 
     sort([cbedfile, "-i"])
 
