@@ -11,7 +11,7 @@ import sys
 import logging
 import fnmatch
 
-from more_itertools import flatten
+from collections.abc import Iterable
 from http.client import HTTPSConnection
 from urllib.parse import urlencode
 from configparser import (
@@ -515,19 +515,8 @@ class OptionParser(OptionP):
         """
         Add image format options for given command line programs.
         """
-        from jcvi.graphics.base import ImageOptions, setup_theme
+        from jcvi.graphics.base import GRAPHIC_FORMATS, ImageOptions, setup_theme
 
-        allowed_format = (
-            "emf",
-            "eps",
-            "pdf",
-            "png",
-            "ps",
-            "raw",
-            "rgba",
-            "svg",
-            "svgz",
-        )
         allowed_fonts = ("Helvetica", "Palatino", "Schoolbook", "Arial")
         allowed_styles = ("darkgrid", "whitegrid", "dark", "white", "ticks")
         allowed_diverge = (
@@ -557,7 +546,7 @@ class OptionParser(OptionP):
         group.add_option(
             "--format",
             default=format,
-            choices=allowed_format,
+            choices=GRAPHIC_FORMATS,
             help="Generate image of format",
         )
         group.add_option(
@@ -965,36 +954,33 @@ class OptionParser(OptionP):
 
     def set_home(self, prog, default=None):
         tag = "--{0}_home".format(prog)
-        default = (
-            default
-            or {
-                "amos": "~/code/amos-code",
-                "trinity": "~/export/trinityrnaseq-2.0.6",
-                "hpcgridrunner": "~/export/hpcgridrunner-1.0.2",
-                "cdhit": "~/export/cd-hit-v4.6.1-2012-08-27",
-                "maker": "~/export/maker",
-                "augustus": "~/export/maker/exe/augustus",
-                "pasa": "~/export/PASApipeline-2.0.2",
-                "gatk": "~/export",
-                "gmes": "~/export/gmes",
-                "gt": "~/export/genometools",
-                "sspace": "~/export/SSPACE-STANDARD-3.0_linux-x86_64",
-                "gapfiller": "~/export/GapFiller_v1-11_linux-x86_64",
-                "pbjelly": "~/export/PBSuite_15.2.20",
-                "picard": "~/export/picard-tools-1.138",
-                "khmer": "~/export/khmer",
-                "tassel": "/usr/local/projects/MTG4/packages/tassel",
-                "tgi": "~/export/seqclean-x86_64",
-                "eddyyeh": "/home/shared/scripts/eddyyeh",
-                "fiona": "~/export/fiona-0.2.0-Linux-x86_64",
-                "fermi": "~/export/fermi",
-                "lobstr": "/mnt/software/lobSTR",
-                "shapeit": "/mnt/software/shapeit",
-                "impute": "/mnt/software/impute",
-                "beagle": "java -jar /mnt/software/beagle.14Jan16.841.jar",
-                "minimac": "/mnt/software/Minimac3/bin",
-            }.get(prog, None)
-        )
+        default = default or {
+            "amos": "~/code/amos-code",
+            "trinity": "~/export/trinityrnaseq-2.0.6",
+            "hpcgridrunner": "~/export/hpcgridrunner-1.0.2",
+            "cdhit": "~/export/cd-hit-v4.6.1-2012-08-27",
+            "maker": "~/export/maker",
+            "augustus": "~/export/maker/exe/augustus",
+            "pasa": "~/export/PASApipeline-2.0.2",
+            "gatk": "~/export",
+            "gmes": "~/export/gmes",
+            "gt": "~/export/genometools",
+            "sspace": "~/export/SSPACE-STANDARD-3.0_linux-x86_64",
+            "gapfiller": "~/export/GapFiller_v1-11_linux-x86_64",
+            "pbjelly": "~/export/PBSuite_15.2.20",
+            "picard": "~/export/picard-tools-1.138",
+            "khmer": "~/export/khmer",
+            "tassel": "/usr/local/projects/MTG4/packages/tassel",
+            "tgi": "~/export/seqclean-x86_64",
+            "eddyyeh": "/home/shared/scripts/eddyyeh",
+            "fiona": "~/export/fiona-0.2.0-Linux-x86_64",
+            "fermi": "~/export/fermi",
+            "lobstr": "/mnt/software/lobSTR",
+            "shapeit": "/mnt/software/shapeit",
+            "impute": "/mnt/software/impute",
+            "beagle": "java -jar /mnt/software/beagle.14Jan16.841.jar",
+            "minimac": "/mnt/software/Minimac3/bin",
+        }.get(prog, None)
         if default is None:  # Last attempt at guessing the path
             try:
                 default = op.dirname(which(prog))
@@ -1319,6 +1305,9 @@ def parse_multi_values(param):
 
 
 def listify(a):
+    """
+    Convert something to a list if it is not already a list.
+    """
     return a if (isinstance(a, list) or isinstance(a, tuple)) else [a]
 
 
@@ -1329,19 +1318,53 @@ def last_updated(a):
     return time.time() - op.getmtime(a)
 
 
-def need_update(a, b):
+def need_update(a: str, b: str, warn: bool = False) -> bool:
     """
     Check if file a is newer than file b and decide whether or not to update
     file b. Can generalize to two lists.
+
+    Args:
+        a: file or list of files
+        b: file or list of files
+        warn: whether or not to print warning message
+
+    Returns:
+        True if file a is newer than file b
     """
     a = listify(a)
     b = listify(b)
 
-    return (
+    should_update = (
         any((not op.exists(x)) for x in b)
         or all((os.stat(x).st_size == 0 for x in b))
         or any(is_newer_file(x, y) for x in a for y in b)
     )
+    if (not should_update) and warn:
+        logging.debug("File `{}` found. Computation skipped.".format(", ".join(b)))
+    return should_update
+
+
+def flatten(input_list: list) -> list:
+    """
+    Flatten a list of lists and stop at the first non-list element.
+    """
+    ans = []
+    for i in input_list:
+        if isinstance(i, Iterable) and not isinstance(i, str):
+            for subc in flatten(i):
+                ans.append(subc)
+        else:
+            ans.append(i)
+    return ans
+
+
+def cleanup(*args):
+    """
+    Remove a bunch of files in args; ignore if not found.
+    """
+    for path in flatten(args):
+        if op.exists(path):
+            os.remove(path)
 
 
 def get_today():
@@ -1444,16 +1467,6 @@ def download(
     return final_filename
 
 
-def remove_if_exists(filename):
-    """Check if a file exists and if so remove it
-
-    Args:
-        filename (str): Path to the local file.
-    """
-    if op.exists(filename):
-        os.remove(filename)
-
-
 def getfilesize(filename, ratio=None):
     rawsize = op.getsize(filename)
     if not filename.endswith(".gz"):
@@ -1473,8 +1486,8 @@ def getfilesize(filename, ratio=None):
     # Heuristic
     heuristicsize = rawsize / ratio
     while size < heuristicsize:
-        size += 2 ** 32
-    if size > 2 ** 32:
+        size += 2**32
+    if size > 2**32:
         logging.warning("Gzip file estimated uncompressed size: {0}.".format(size))
 
     return size
@@ -1927,7 +1940,7 @@ def notify(args):
     g1.add_option(
         "--api",
         default="pushover",
-        choices=list(flatten(available_push_api.values())),
+        choices=flatten(available_push_api.values()),
         help="Specify API used to send the push notification",
     )
     g1.add_option(
@@ -2067,7 +2080,7 @@ def waitpid(args):
     """
     import shlex
 
-    valid_notif_methods.extend(list(flatten(available_push_api.values())))
+    valid_notif_methods.extend(flatten(available_push_api.values()))
 
     p = OptionParser(waitpid.__doc__)
     p.add_option(
