@@ -7,6 +7,7 @@ import sys
 import logging
 
 logging.getLogger("matplotlib").setLevel(logging.WARNING)
+logging.getLogger("numexpr").setLevel(logging.WARNING)
 logging.getLogger("PIL").setLevel(logging.INFO)
 
 from functools import partial
@@ -39,6 +40,29 @@ from jcvi.apps.base import glob, listify, datadir, sample_N, which
 logging.getLogger().setLevel(logging.DEBUG)
 
 
+CHARS = {
+    "&": r"\&",
+    "%": r"\%",
+    "$": r"\$",
+    "#": r"\#",
+    "_": r"\_",
+    "{": r"\{",
+    "}": r"\}",
+}
+
+GRAPHIC_FORMATS = (
+    "emf",
+    "eps",
+    "pdf",
+    "png",
+    "ps",
+    "raw",
+    "rgba",
+    "svg",
+    "svgz",
+)
+
+
 def is_usetex():
     """Check if latex command is available"""
     return bool(which("latex")) and bool(which("lp"))
@@ -130,17 +154,6 @@ class AbstractLayout(LineFile):
         return "\n".join(str(x) for x in self)
 
 
-CHARS = {
-    "&": r"\&",
-    "%": r"\%",
-    "$": r"\$",
-    "#": r"\#",
-    "_": r"\_",
-    "{": r"\{",
-    "}": r"\}",
-}
-
-
 def linear_blend(from_color, to_color, fraction=0.5):
     """Interpolate a new color between two colors.
 
@@ -274,6 +287,24 @@ def panel_labels(ax, labels, size=16):
         ax.text(xx, yy, panel_label, size=size, ha="center", va="center")
 
 
+def update_figname(figname: str, format: str) -> str:
+    """Update the name of a figure to include the format.
+
+    Args:
+        figname (str): Path to the figure
+        format (str): Figure format, must be one of GRAPHIC_FORMATS
+
+    Returns:
+        str: New file path
+    """
+    _, ext = op.splitext(figname)
+    if ext.strip(".") in GRAPHIC_FORMATS:  # User suffix has precedence
+        return figname
+    # When the user has not supplied a format in the filename, use the requested format
+    assert format in GRAPHIC_FORMATS, "Invalid format"
+    return figname + "." + format
+
+
 def savefig(figname, dpi=150, iopts=None, cleanup=True):
     try:
         format = figname.rsplit(".", 1)[-1].lower()
