@@ -8,7 +8,6 @@ import os.path as op
 import os
 import csv
 import sys
-import vcf
 import logging
 import shutil
 import json
@@ -24,6 +23,11 @@ from Bio.SeqRecord import SeqRecord
 from itertools import product
 from natsort import natsorted
 
+try:
+    import vcf
+except ImportError:
+    pass
+
 from jcvi.graphics.base import (
     FancyArrow,
     normalize_axes,
