@@ -7,7 +7,7 @@
 # Created by Haibao Tang on 12/02/19
 # Copyright © 2019 Haibao Tang. All rights reserved.
 #
-
+import logging
 import os.path as op
 import sys
 from random import random, sample
@@ -17,7 +17,8 @@ import numpy as np
 import matplotlib.pyplot as plt
 
 from jcvi.apps.base import OptionParser, ActionDispatcher, mkdir
-from jcvi.graphics.base import normalize_axes, adjust_spines, savefig
+from jcvi.graphics.base import adjust_spines, markup, normalize_axes, savefig
+from jcvi.utils.validator import validate_in_choices
 
 SoColor = "#7436a4"  # Purple
 SsColor = "#5a8340"  # Green
@@ -97,11 +98,11 @@ class Genome:
         # Randomly assign the rest, singleton chromosomes
         for group, chromosomes in groupby(singleton_chromosomes, key=prefix):
             chromosomes = list(chromosomes)
-            halfN = len(chromosomes) // 2
+            halfn = len(chromosomes) // 2
             # Odd number, e.g. 5, equal chance to be 2 or 3
             if len(chromosomes) % 2 != 0 and random() < 0.5:
-                halfN += 1
-            gamete_chromosomes += sorted(sample(chromosomes, halfN))
+                halfn += 1
+            gamete_chromosomes += sorted(sample(chromosomes, halfn))
         return Genome.make(self.name + " gamete", gamete_chromosomes)
 
     def mate_nplusn(self, name, other_genome, verbose=True):
@@ -114,7 +115,7 @@ class Genome:
         )
         return Genome.make(name, f1_chromosomes)
 
-    def mate_2xnplusn(self, name, other_genome, verbose=True):
+    def mate_nx2plusn(self, name, other_genome, verbose=True):
         if verbose:
             print(
                 f"Crossing '{self.name}' x '{other_genome.name}' (2xn+n)",
@@ -185,7 +186,7 @@ class GenomeSummary:
             round(np.min(a), precision),
             round(np.max(a), precision),
         )
-        s = f"{tag} chr: {mean:.0f}"
+        s = f"*{tag}* chr: {mean:.0f}"
         if min == mean and max == mean:
             return s
         return s + f" ({min:.0f}-{max:.0f})"
@@ -196,11 +197,11 @@ class GenomeSummary:
             round(np.min(a), precision),
             round(np.max(a), precision),
         )
-        s = f"{tag}\%: {mean:.1f}\%"
+        s = f"*{tag}*%: {mean:.1f}%"
         print(s)
         if min == mean and max == mean:
             return s
-        return s + f" ({min:.1f}-{max:.1f}\%)"
+        return s + f" ({min:.1f}-{max:.1f}%)"
 
     @property
     def percent_SO_summary(self):
@@ -219,35 +220,37 @@ class GenomeSummary:
         return self._summary(self.SS_data, "Ss")
 
 
-def simulate_F1(SO, SS, verbose=False):
-    SO_SS_F1_2xnplusn = SO.mate_2xnplusn("SOxSS F1", SS, verbose=verbose)
-    if verbose:
-        SO_SS_F1_2xnplusn.print_summary()
-    return SO_SS_F1_2xnplusn
-
-
-def simulate_F2(SO, SS, verbose=False):
-    SO_SS_F1_2xnplusn = simulate_F1(SO, SS, verbose=verbose)
-    SO_SS_F2_nplusn = SO_SS_F1_2xnplusn.mate_nplusn(
-        "SOxSS F2", SO_SS_F1_2xnplusn, verbose=verbose
+def simulate_F1(SO, SS, mode="nx2+n", verbose=False):
+    SO_SS_F1 = (
+        SO.mate_nx2plusn("SOxSS F1", SS, verbose=verbose)
+        if mode == "nx2+n"
+        else SO.mate_2nplusn("SOxSS F1", SS, verbose=verbose)
     )
+    if verbose:
+        SO_SS_F1.print_summary()
+    return SO_SS_F1
+
+
+def simulate_F2(SO, SS, mode="nx2+n", verbose=False):
+    SO_SS_F1 = simulate_F1(SO, SS, mode=mode, verbose=verbose)
+    SO_SS_F2_nplusn = SO_SS_F1.mate_nplusn("SOxSS F2", SO_SS_F1, verbose=verbose)
     if verbose:
         SO_SS_F2_nplusn.print_summary()
     return SO_SS_F2_nplusn
 
 
-def simulate_F1intercross(SO, SS, verbose=False):
-    SO_SS_F1_2xnplusn_1 = simulate_F1(SO, SS, verbose=verbose)
-    SO_SS_F1_2xnplusn_2 = simulate_F1(SO, SS, verbose=verbose)
-    SO_SS_F1intercross_nplusn = SO_SS_F1_2xnplusn_1.mate_nplusn(
-        "SOxSS F1 intercross", SO_SS_F1_2xnplusn_2, verbose=verbose
+def simulate_F1intercross(SO, SS, mode="nx2+n", verbose=False):
+    SO_SS_F1_1 = simulate_F1(SO, SS, mode=mode, verbose=verbose)
+    SO_SS_F1_2 = simulate_F1(SO, SS, mode=mode, verbose=verbose)
+    SO_SS_F1intercross_nplusn = SO_SS_F1_1.mate_nplusn(
+        "SOxSS F1 intercross", SO_SS_F1_2, verbose=verbose
     )
     return SO_SS_F1intercross_nplusn
 
 
-def simulate_BCn(n, SO, SS, verbose=False):
-    SS_SO_F1_2xnplusn = simulate_F1(SO, SS, verbose=verbose)
-    SS_SO_BC1_2xnplusn, SS_SO_BC2_nplusn, SS_SO_BC3_nplusn, SS_SO_BC4_nplusn = (
+def simulate_BCn(n, SO, SS, mode="nx2+n", verbose=False):
+    SS_SO_F1 = simulate_F1(SO, SS, mode=mode, verbose=verbose)
+    SS_SO_BC1, SS_SO_BC2_nplusn, SS_SO_BC3_nplusn, SS_SO_BC4_nplusn = (
         None,
         None,
         None,
@@ -255,14 +258,15 @@ def simulate_BCn(n, SO, SS, verbose=False):
     )
     # BC1
     if n >= 1:
-        SS_SO_BC1_2xnplusn = SO.mate_2xnplusn(
-            "SSxSO BC1", SS_SO_F1_2xnplusn, verbose=verbose
+        SS_SO_BC1 = (
+            # Expecting one more round of female restitution in BC1
+            SO.mate_nx2plusn("SSxSO BC1", SS_SO_F1, verbose=verbose)
+            if mode == "nx2+n"
+            else SO.mate_2nplusn("SSxSO BC1", SS_SO_F1, verbose=verbose)
         )
     # BC2
     if n >= 2:
-        SS_SO_BC2_nplusn = SO.mate_nplusn(
-            "SSxSO BC2", SS_SO_BC1_2xnplusn, verbose=verbose
-        )
+        SS_SO_BC2_nplusn = SO.mate_nplusn("SSxSO BC2", SS_SO_BC1, verbose=verbose)
     # BC3
     if n >= 3:
         SS_SO_BC3_nplusn = SO.mate_nplusn(
@@ -275,19 +279,19 @@ def simulate_BCn(n, SO, SS, verbose=False):
         )
     return [
         None,
-        SS_SO_BC1_2xnplusn,
+        SS_SO_BC1,
         SS_SO_BC2_nplusn,
         SS_SO_BC3_nplusn,
         SS_SO_BC4_nplusn,
     ][n]
 
 
-def plot_summary(ax, samples):
+def plot_summary(ax, samples: list[Genome]) -> GenomeSummary:
     """Plot the distribution of chromosome numbers given simulated samples.
 
     Args:
         ax (Axes): Matplotlib axes.
-        samples ([Genome]): Summarized genomes.
+        samples (list[Genome]): Summarized genomes.
 
     Returns:
         GenomeSummary: Summary statistics of simulated genomes.
@@ -311,13 +315,39 @@ def plot_summary(ax, samples):
         assert total_tag == "Total"
         percent_SO = total_so_size * 100.0 / total_size
         percent_SO_data.append(percent_SO)
+    # Avoid overlapping bars
+    SS_counter, SO_counter = Counter(SS_data), Counter(SO_data)
+    overlaps = SS_counter.keys() & SO_counter.keys()
     shift = 0.5  # used to offset bars a bit to avoid cluttering
-    x, y = zip(*sorted(Counter(SS_data).items()))
-    ax.bar(np.array(x) - shift, y, color=SsColor, ec=SsColor)
-    x, y = zip(*sorted(Counter(SO_data).items()))
-    ax.bar(np.array(x) + shift, y, color=SoColor, ec=SoColor)
+    if overlaps:
+        for overlap in overlaps:
+            logging.debug(f"Modify bar offsets at {overlap} due to SS and SO overlaps")
+            SS_counter[overlap - shift] = SS_counter[overlap]
+            del SS_counter[overlap]
+            SO_counter[overlap + shift] = SO_counter[overlap]
+            del SO_counter[overlap]
+
+    def modify_range_end(d: dict, value: int):
+        if value not in d:
+            return
+        # Has data at the range end, but no adjacent data points (i.e. isolated bar)
+        if value in d and (value - 1 in d or value + 1 in d):
+            return
+        logging.debug(f"Modify bar offsets at {value} due to end of range ends")
+        d[value - shift if value else value + shift] = d[80]
+        del d[value]
+
+    modify_range_end(SS_counter, 0)
+    modify_range_end(SS_counter, 80)
+    modify_range_end(SO_counter, 0)
+    modify_range_end(SO_counter, 80)
+
+    x, y = zip(*sorted(SS_counter.items()))
+    ax.bar(np.array(x), y, color=SsColor, ec=SsColor)
+    x, y = zip(*sorted(SO_counter.items()))
+    ax.bar(np.array(x), y, color=SoColor, ec=SoColor)
     ax.set_xlim(80, 0)
-    ax.set_ylim(0, 500)
+    ax.set_ylim(0, len(samples) / 2)
     ax.set_yticks([])
     summary = GenomeSummary(SO_data, SS_data, percent_SO_data)
 
@@ -328,20 +358,24 @@ def plot_summary(ax, samples):
         va="center",
         transform=ax.transAxes,
     )
-    ax.text(0.75, 0.85, summary.SS_summary, color=SsColor, **summary_style)
-    ax.text(0.75, 0.65, summary.percent_SS_summary, color=SsColor, **summary_style)
-    ax.text(0.25, 0.85, summary.SO_summary, color=SoColor, **summary_style)
-    ax.text(0.25, 0.65, summary.percent_SO_summary, color=SoColor, **summary_style)
+    ax.text(0.75, 0.85, markup(summary.SS_summary), color=SsColor, **summary_style)
+    ax.text(
+        0.75, 0.65, markup(summary.percent_SS_summary), color=SsColor, **summary_style
+    )
+    ax.text(0.25, 0.85, markup(summary.SO_summary), color=SoColor, **summary_style)
+    ax.text(
+        0.25, 0.65, markup(summary.percent_SO_summary), color=SoColor, **summary_style
+    )
 
     return summary
 
 
-def write_chromosomes(genomes, filename):
+def write_chromosomes(genomes: list[Genome], filename: str):
     """Write simulated chromosomes to file
 
     Args:
-        genomes (List[Genome]): List of simulated genomes.
-        filename: File path to write to.
+        genomes (list[Genome]): List of simulated genomes.
+        filename (str): File path to write to.
     """
     print(f"Write chromosomes to `{filename}`", file=sys.stderr)
     with open(filename, "w") as fw:
@@ -349,11 +383,30 @@ def write_chromosomes(genomes, filename):
             print(genome, file=fw)
 
 
+def write_SO_percent(summary: GenomeSummary, filename: str):
+    """Write SO % to file
+
+    Args:
+        summary (GenomeSummary): List of simulated genomes.
+        filename (str): File path to write to.
+    """
+    print(f"Write SO percent to `{filename}`", file=sys.stderr)
+    with open(filename, "w") as fw:
+        print("\n".join(str(x) for x in sorted(summary.percent_SO_data)), file=fw)
+
+
 def simulate(args):
     """
-    %prog simulate
+    %prog simulate [2n+n|nx2+n]
 
-    Run simulation on female restitution.
+    Run simulation on female restitution. There are two modes:
+    - 2n+n: merger between a somatic and a germline
+    - nx2+n: merger between a doubled germline and a germline
+
+    These two modes would impact the sequence diversity in the progeny
+    genome in F1, F2, BCn ... the goal of this simulation, is thus to
+    understand the mode and the spread of such diversity in the hybrid
+    progenies.
     """
     import seaborn as sns
 
@@ -366,10 +419,15 @@ def simulate(args):
         action="store_true",
         help="Verbose logging during simulation",
     )
+    p.add_option("-N", default=10000, type="int", help="Number of simulated samples")
     opts, args, iopts = p.set_image_options(args, figsize="6x6")
-    if len(args) != 0:
+    if len(args) != 1:
         sys.exit(not p.print_help())
 
+    (mode,) = args
+    validate_in_choices(mode, ["2n+n", "nx2+n"], "Mode")
+    logging.info(f"Transmission: {mode}")
+
     # Construct a composite figure with 6 tracks
     fig = plt.figure(1, (iopts.w, iopts.h))
     root = fig.add_axes([0, 0, 1, 1])
@@ -398,16 +456,17 @@ def simulate(args):
     SO = Genome("SO", "SO", 8, 10)
 
     verbose = opts.verbose
-    all_F1s = [simulate_F1(SO, SS, verbose=verbose) for _ in range(1000)]
-    all_F2s = [simulate_F2(SO, SS, verbose=verbose) for _ in range(1000)]
-    all_BC1s = [simulate_BCn(1, SO, SS, verbose=verbose) for _ in range(1000)]
-    all_BC2s = [simulate_BCn(2, SO, SS, verbose=verbose) for _ in range(1000)]
-    all_BC3s = [simulate_BCn(3, SO, SS, verbose=verbose) for _ in range(1000)]
-    all_BC4s = [simulate_BCn(4, SO, SS, verbose=verbose) for _ in range(1000)]
+    N = opts.N
+    all_F1s = [simulate_F1(SO, SS, mode=mode, verbose=verbose) for _ in range(N)]
+    all_F2s = [simulate_F2(SO, SS, mode=mode, verbose=verbose) for _ in range(N)]
+    all_BC1s = [simulate_BCn(1, SO, SS, mode=mode, verbose=verbose) for _ in range(N)]
+    all_BC2s = [simulate_BCn(2, SO, SS, mode=mode, verbose=verbose) for _ in range(N)]
+    all_BC3s = [simulate_BCn(3, SO, SS, mode=mode, verbose=verbose) for _ in range(N)]
+    all_BC4s = [simulate_BCn(4, SO, SS, mode=mode, verbose=verbose) for _ in range(N)]
 
     # Plotting
-    plot_summary(ax1, all_F1s)
-    plot_summary(ax2, all_F2s)
+    all_F1s_summary = plot_summary(ax1, all_F1s)
+    all_F2s_summary = plot_summary(ax2, all_F2s)
     plot_summary(ax3, all_BC1s)
     plot_summary(ax4, all_BC2s)
     plot_summary(ax5, all_BC3s)
@@ -417,12 +476,12 @@ def simulate(args):
     xx = xpad / 2
     for (title, subtitle), yy in zip(
         (
-            ("F1", None),
-            ("F2", None),
-            ("BC1", None),
-            ("BC2", None),
-            ("BC3", None),
-            ("BC4", None),
+            (r"$\mathrm{F_1}$", None),
+            (r"$\mathrm{F_2}$", None),
+            (r"$\mathrm{BC_1}$", None),
+            (r"$\mathrm{BC_2}$", None),
+            (r"$\mathrm{BC_3}$", None),
+            (r"$\mathrm{BC_4}$", None),
         ),
         yy_positions,
     ):
@@ -449,9 +508,13 @@ def simulate(args):
     adjust_spines(axes[-1], ["bottom"], outward=True)
     normalize_axes(root)
 
-    savefig("plotter.pdf", dpi=120)
+    # Title
+    mode_title = r"$n_1\times2 + n_2$" if mode == "nx2+n" else r"$2n + n$"
+    root.text(0.5, 0.95, f"Transmission: {mode_title}", ha="center")
 
-    outdir = "simulations"
+    savefig(f"{mode}.pdf", dpi=120)
+
+    outdir = f"simulations_{mode}"
     mkdir(outdir)
     # Write chromosomes to disk
     for genomes, filename in (
@@ -464,6 +527,13 @@ def simulate(args):
     ):
         write_chromosomes(genomes, op.join(outdir, filename))
 
+    # Write the SO percent in simulated samples so that we can compute P-value
+    for summary, SO_percent_filename in (
+        (all_F1s_summary, "all_F1s_SO_percent"),
+        (all_F2s_summary, "all_F2s_SO_percent"),
+    ):
+        write_SO_percent(summary, op.join(outdir, SO_percent_filename))
+
 
 def _get_sizes(filename, prefix_length, tag, target_size=None):
     """Returns a dictionary of chromome lengths from a given file.
@@ -519,8 +589,8 @@ def prepare(args):
 
     solist, sslist = args
     # The haploid set of LA Purple is 957.2 Mb and haploid set of US56-14-4 is 732.5 Mb
-    sizes = _get_sizes(solist, 5, "SO", target_size=957.2 * 1e6)
-    sizes.update(_get_sizes(sslist, 4, "SS", target_size=732.5 * 1e6))
+    sizes = _get_sizes(solist, 5, "SO", target_size=int(957.2 * 1e6))
+    sizes.update(_get_sizes(sslist, 4, "SS", target_size=int(732.5 * 1e6)))
     print(sizes)
 
 
